@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4; # local revision: b
+our $VERSION = 2.2;
 
 1;
 
@@ -37,8 +37,8 @@ sub set_days {
     # probably wouldn't have been my first choice, but that's how ATR is defined.
 
     $this->{days} = $arg;
-    $this->{R1}  = ($arg-1)/$arg;
-    $this->{R} = 1/$arg;
+    $this->{R}  = ($arg-1)/$arg;
+    $this->{R1} = 1/$arg;
 }
 
 sub insert {
@@ -46,7 +46,7 @@ sub insert {
 
     my $y_close = $this->{y_close};
     while( defined( my $point = shift ) ) {
-        croak "insert takes three tuple [high, low, close]" unless ref $point eq "ARRAY" and @$point == 3;
+        croak "insert takes three touples [high, low, close]" unless ref $point eq "ARRAY" and @$point == 3;
         my ($t_high, $t_low, $t_close) = @$point;
 
         if( defined $y_close ) {
@@ -59,7 +59,7 @@ sub insert {
                $true_range = $C if $C > $true_range;
 
             if( defined(my $atr = $this->{ATR}) ) {
-                $this->{ATR} = $this->{R1} * $atr + $this->{R} * $true_range;
+                $this->{ATR} = $this->{R} * $atr + $this->{R1} * $true_range;
 
             } else {
                 my $p;
@@ -70,7 +70,6 @@ sub insert {
                        $sum += $true_range;
 
                     $this->{ATR} = $sum / $N;
-                    delete $this->{_p};
 
                 } else {
                     push @{$this->{_p}}, $true_range;
@@ -97,6 +96,14 @@ sub insert {
     $this->{y_close} = $y_close;
 }
 
+sub start_with {
+    my $this = shift;
+    croak "you must provide: (yesterday's close, yesterday's ATR)" unless @_ == 2;
+
+    $this->{y_close} = shift;
+    $this->{ATR}     = shift;
+}
+
 sub query {
     my $this = shift;
 
@@ -141,6 +148,9 @@ Math::Business::ATR - Technical Analysis: Average True Range
       print "ATR: n/a.\n";
   }
 
+  # you may use this to kick start 
+  $atr->start_with( $yesterday_close, $old_atr );
+
 =head1 RESEARCHER
 
 The ATR was designed by J. Welles Wilder Jr circa 1978.
@@ -162,9 +172,6 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
-There is also a mailing list with very light traffic that you might want to
-join: L<http://groups.google.com/group/stockmonkey/>.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
@@ -176,7 +183,7 @@ Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
 
 =head1 SEE ALSO
 
-perl(1), L<Math::Business::StockMonkey>, L<Math::Business::StockMonkey::FAQ>, L<Math::Business::StockMonkey::CookBook>
+perl(1)
 
 L<http://fxtrade.oanda.com/learn/graphs/indicators/atr.shtml>
 
