@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4;
+our $VERSION = 2.2;
 
 1;
 
@@ -53,7 +53,6 @@ sub insert {
                    $sum += $_ for @$p;
 
                 $this->{EMA} = ( $this->{R} * $Yt ) + ( $this->{R1} * ($sum/$N) );
-                delete $this->{_p};
 
             } else {
                 push @{$this->{_p}}, $Yt;
@@ -62,6 +61,13 @@ sub insert {
     }
 }
 
+sub start_with {
+    my $this = shift;
+       $this->{EMA} = shift;
+
+    croak "undefined arg to start_with" unless defined $this->{EMA};
+}
+
 sub query {
     my $this = shift;
 
@@ -97,6 +103,10 @@ Math::Business::EMA - Technical Analysis: Exponential Moving Average
       print "value: n/a.\n";
   }
 
+To avoid recalculating huge lists when you add a few new values on the end:
+
+  $avg->start_with( $the_last_calculated_value );
+
 For short, you can skip the set_days() by suppling the setting to new():
 
   my $longer_ema = new Math::Business::EMA(10);
@@ -111,9 +121,6 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
-There is also a mailing list with very light traffic that you might want to
-join: L<http://groups.google.com/group/stockmonkey/>.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
@@ -125,7 +132,7 @@ Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
 
 =head1 SEE ALSO
 
-perl(1), L<Math::Business::EMA>, L<Math::Business::StockMonkey>, L<Math::Business::StockMonkey::FAQ>, L<Math::Business::StockMonkey::CookBook>
+perl(1), Math::Business::EMA(3).
 
 L<http://en.wikipedia.org/wiki/Exponential_moving_average>
 
