@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 2.4; # local revision: b
+our $VERSION = 2.2;
 
 use Math::Business::SMA;
 use Math::Business::EMA;
@@ -38,10 +38,7 @@ sub set_alpha {
     my $this  = shift;
     my $alpha = shift;
 
-    # NOTE: this alpha is different than you might think ... it's really inverse alpha
-    # Wilder uses alpha=14 instead of alpha=(1/14) like you might expect
-
-    my $days = 2*$alpha - 1; # so days is 2*$alpha-1 instead of the expected 2*(1/$alpha)-1
+    my $days = 2*$alpha - 1;
 
     eval { $this->set_days( $days ) };
     croak "set_alpha() is basically set_days(2*$alpha-1), which complained: $@" if $@;
@@ -126,6 +123,19 @@ sub insert {
     $this->{cy} = $close_yesterday;
 }
 
+sub start_with {
+    my $this = shift;
+    my ($U,$D,$cy) = @_;
+
+    $this->{U}->start_with( $U );
+    $this->{D}->start_with( $U );
+    $this->{cy} = $cy;
+}
+
+sub query_EMA_U { my $this = shift; $this->{U}->query }
+sub query_EMA_D { my $this = shift; $this->{D}->query }
+sub query_cy    { my $this = shift; $this->{cy} }
+
 sub query {
     my $this = shift;
 
@@ -143,13 +153,12 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
   use Math::Business::RSI;
 
   my $rsi = new Math::Business::RSI;
-     $rsi->set_alpha(14); # issues a set days of 2*14-1
-     $rsi->set_days(27);  # equivilent to set_alpha(14)
+     $rsi->set_days(14);
 
-  # equivelent to set_days(27)/set_alpha(14):
+  # alternatively/equivilently
   my $rsi = new Math::Business::RSI(14);
 
-  # or to just get the recommended model ... set_alpha(14)
+  # or to just get the recommended model ... (14)
   my $rsi = Math::Business::RSI->recommended;
 
   my @closing_values = qw(
@@ -168,6 +177,14 @@ Math::Business::RSI - Technical Analysis: Relative Strength Index
       print "RSI: n/a.\n";
   }
 
+  # you may use this to kick start 
+  $rsi->start_with( $U, $D, $cy );
+
+  # you may fetch those values with these
+  my $U  = $rsi->query_EMA_U;
+  my $D  = $rsi->query_EMA_D;
+  my $cy = $rsi->query_cy; # (close yesterday)
+
 =head1 RESEARCHER
 
 The RSI was designed by J. Welles Wilder Jr in 1978.
@@ -179,15 +196,6 @@ use thresholds of 80 and 20.
 Therefore, moving above the upper threshold is a selling signal, whlie moving
 below the lower threshold is a signal to buy.
 
-Oddly, RSI(14) uses a "smoothing period" of 14 days -- referring to an alpha of
-1/14.  This means the EMA[N]u/EMA[N]d has N set to 27.  This also means the
-alpha is upside of other alpha you might see.  RSI(14) actually uses an alpha
-of ~0.0714, but set_alpha() takes the inverse to make C<$rsi->set_alpha(14)>
-work.
-
-If all of the above seems really confusing, no worries: RSI(14) means
-C<set_alpha(14)> (or C<new(14)> and is equivelent to C<set_days(27)>.
-
 =head2 Cutler
 
 There are differing schools of thought on how to calculate this and how
@@ -218,9 +226,6 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
-There is also a mailing list with very light traffic that you might want to
-join: L<http://groups.google.com/group/stockmonkey/>.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
@@ -232,7 +237,7 @@ Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
 
 =head1 SEE ALSO
 
-perl(1), L<Math::Business::StockMonkey>, L<Math::Business::StockMonkey::FAQ>, L<Math::Business::StockMonkey::CookBook>
+perl(1)
 
 L<http://en.wikipedia.org/wiki/Relative_Strength_Index>
 
